Cached<T> class

Constructors

Cached({String? path, CacheFromJson<T>? fromJson, CacheToJson<T>? toJson})
const

Properties

fromJson CacheFromJson<T>?
final
hashCode int
The hash code for this object.
no setterinherited
path String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toJson CacheToJson<T>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited